netapp_ontap.resources.nfs_service API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.nfs_service`

Copyright © 2020 NetApp Inc. All rights reserved.

### Retrieving an NFS configuration

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NfsService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(NfsService.get_collection()))

### Creating an NFS configuration for an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NfsService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NfsService()
        resource.svm.uuid = "1cd8a442-86d1-11e0-ae1c-123478563412"
        resource.protocol.v4_id_domain = "nfs-nsr-w01.rtp.netapp.com"
        resource.vstorage_enabled = True
        resource.post(hydrate=True)
        print(resource)

### Updating an NFS configuration for an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NfsService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NfsService(**{"svm.uuid": "4a415601-548c-11e8-a21d-0050568bcbc9"})
        resource.protocol.v4_id_domain = "nfs-nsr-w01.rtp.netapp.com"
        resource.vstorage_enabled = False
        resource.patch()

### Deleting an NFS configuration for an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NfsService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NfsService(**{"svm.uuid": "4a415601-548c-11e8-a21d-0050568bcbc9"})
        resource.delete()

## Performance monitoring

Performance of the SVM can be monitored by the `metric.*` and `statistics.*` properties. These show the performance of the SVM in terms of IOPS, latency and throughput. The `metric.*` properties denote an average whereas `statistics.*` properties denote a real-time monotonically increasing value aggregated across all nodes.

## Classes

`class NfsService (*args, **kwargs)`

  Allows interaction with NfsService objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the NFS configuration of SVMs.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `vserver nfs show`
    - `vserver nfs status`

    ### Learn more

    - `DOC /protocols/nfs/services`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes the NFS configuration of an SVM.

    ### Related ONTAP commands

    - `vserver nfs delete`

    ### Learn more

    - `DOC /protocols/nfs/services`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the NFS configuration of SVMs.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `vserver nfs show`
    - `vserver nfs status`

    ### Learn more

    - `DOC /protocols/nfs/services`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the NFS configuration of SVMs.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `vserver nfs show`
    - `vserver nfs status`

    ### Learn more

    - `DOC /protocols/nfs/services`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the NFS configuration of an SVM.

    ### Related ONTAP commands

    - `vserver nfs modify`
    - `vserver nfs on`
    - `vserver nfs off`
    - `vserver nfs start`
    - `vserver nfs stop`

    ### Learn more

    - `DOC /protocols/nfs/services`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes the NFS configuration of an SVM.

    ### Related ONTAP commands

    - `vserver nfs delete`

    ### Learn more

    - `DOC /protocols/nfs/services`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the NFS configuration of an SVM.

    ### Related ONTAP commands

    - `vserver nfs show`
    - `vserver nfs status`

    ### Learn more

    - `DOC /protocols/nfs/services`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the NFS configuration of an SVM.

    ### Related ONTAP commands

    - `vserver nfs modify`
    - `vserver nfs on`
    - `vserver nfs off`
    - `vserver nfs start`
    - `vserver nfs stop`

    ### Learn more

    - `DOC /protocols/nfs/services`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates an NFS configuration for an SVM.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM for which to create the NFS configuration.

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `enabled` - true * `state` - online * `transport.udp_enabled` - true * `transport.tcp_enabled` - true * `protocol.v3_enabled` - true * `protocol.v3_64bit_identifiers_enabled` - false * `protocol.v4_id_domain` - defaultv4iddomain.com * `protocol.v4_64bit_identifiers_enabled` - true * `protocol.v4_enabled` - false * `protocol.v41_enabled` - false * `protocol.v40_features.acl_enabled` - false * `protocol.v40_features.read_delegation_enabled` - false * `protocol.v40_features.write_delegation_enabled` - false * `protocol.v41_features.acl_enabled` - false * `protocol.v41_features.read_delegation_enabled` - false * `protocol.v41_features.write_delegation_enabled` - false * `protocol.v41_features.pnfs_enabled` - false * `vstorage_enabled` - false * `rquota_enabled` - false * `showmount_enabled` - true * `auth_sys_extended_groups_enabled` - false * `extended_groups_limit` - 32 * `positive_cached_credential_ttl` - 7200000

    ### Related ONTAP commands

    - `vserver nfs create`

    ### Learn more

    - `DOC /protocols/nfs/services`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class NfsServiceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NfsService object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `auth_sys_extended_groups_enabled GET POST PATCH`

    Specifies whether or not extended groups support over AUTH_SYS is enabled.

  `enabled GET POST PATCH`

    Specifies if the NFS service is administratively enabled.

  `extended_groups_limit GET POST PATCH`

    Specifies the maximum auxillary groups supported over AUTH_SYS and RPCSEC_GSS.

    Example: 32

  `links GET`

    The links field of the nfs_service.

  `metric GET`

    The metric field of the nfs_service.

  `positive_cached_credential_ttl GET POST PATCH`

    Specifies the time to live value (in msecs) of a positive cached credential

    Example: 7200000

  `protocol GET POST PATCH`

    The protocol field of the nfs_service.

  `rquota_enabled GET POST PATCH`

    Specifies whether or not the remote quota feature is enabled.

  `showmount_enabled GET POST PATCH`

    Specifies whether or not the showmount feature is enabled.

  `state GET`

    Specifies the state of the NFS service on the SVM. The following values are supported:

              * online - NFS server is ready to accept client requests.
              * offline - NFS server is not ready to accept client requests.

    Valid choices:

    - online
    - offline
  `statistics GET`

    The statistics field of the nfs_service.

  `svm GET POST PATCH`

    The svm field of the nfs_service.

  `transport GET POST PATCH`

    The transport field of the nfs_service.

  `vstorage_enabled GET POST PATCH`

    Specifies whether or not the VMware vstorage feature is enabled.